@@ -125,24 +125,24 @@ RadioView::RadioView(const TQString &name)
     m_pauseMenu     = new TDEPopupMenu(btnPower);
     m_pauseMenu->insertItem(SmallIcon("tderadio_pause"),
                             i18n("Pause TDERadio"),
-                            this, TQT_SLOT(slotPause()));
+                            this, TQ_SLOT(slotPause()));
     btnPower->setPopupDelay(200);
 
     m_RecordingMenu = new TDEPopupMenu(btnRecording);
     m_RecordingMenu->insertItem(SmallIcon("tderadio_record"),
                                 i18n("Start Recording"),
                                 POPUP_ID_START_RECORDING_DEFAULT);
-    TQObject::connect(m_RecordingMenu, TQT_SIGNAL(activated(int)),
-                     this,            TQT_SLOT(slotRecordingMenu(int)));
+    TQObject::connect(m_RecordingMenu, TQ_SIGNAL(activated(int)),
+                     this,            TQ_SLOT(slotRecordingMenu(int)));
     btnRecording->setPopup(m_RecordingMenu);
 
 
     m_SnoozeMenu   = new TDEPopupMenu(btnSnooze);
-    m_SnoozeMenu->insertItem(i18n("5 min"),  this, TQT_SLOT(slotSnooze(int)), 0,  5);
-    m_SnoozeMenu->insertItem(i18n("10 min"), this, TQT_SLOT(slotSnooze(int)), 0, 10);
-    m_SnoozeMenu->insertItem(i18n("15 min"), this, TQT_SLOT(slotSnooze(int)), 0, 15);
-    m_SnoozeMenu->insertItem(i18n("30 min"), this, TQT_SLOT(slotSnooze(int)), 0, 30);
-    m_SnoozeMenu->insertItem(i18n("60 min"), this, TQT_SLOT(slotSnooze(int)), 0, 60);
+    m_SnoozeMenu->insertItem(i18n("5 min"),  this, TQ_SLOT(slotSnooze(int)), 0,  5);
+    m_SnoozeMenu->insertItem(i18n("10 min"), this, TQ_SLOT(slotSnooze(int)), 0, 10);
+    m_SnoozeMenu->insertItem(i18n("15 min"), this, TQ_SLOT(slotSnooze(int)), 0, 15);
+    m_SnoozeMenu->insertItem(i18n("30 min"), this, TQ_SLOT(slotSnooze(int)), 0, 30);
+    m_SnoozeMenu->insertItem(i18n("60 min"), this, TQ_SLOT(slotSnooze(int)), 0, 60);
     btnSnooze->setPopup(m_SnoozeMenu);
     btnSnooze->setPopupDelay(200);
 
@@ -169,20 +169,20 @@ RadioView::RadioView(const TQString &name)
     comboStations->setMinimumHeight(28);
 
 
-    TQObject::connect(btnPower,      TQT_SIGNAL(toggled(bool)),
-                     this,          TQT_SLOT(slotPower(bool)));
-    TQObject::connect(btnQuit,       TQT_SIGNAL(clicked()),
-                     kapp,          TQT_SLOT(quit()));
-    TQObject::connect(btnConfigure,  TQT_SIGNAL(toggled(bool)),
-                     this,          TQT_SLOT(slotConfigure(bool)));
-    TQObject::connect(btnRecording,  TQT_SIGNAL(clicked()),
-                     this,          TQT_SLOT(slotRecord()));
-    TQObject::connect(btnSnooze,     TQT_SIGNAL(toggled(bool)),
-                     this,          TQT_SLOT(slotSnooze(bool)));
-    TQObject::connect(comboStations, TQT_SIGNAL(activated(int)),
-                     this,          TQT_SLOT(slotComboStationSelected(int)));
-    TQObject::connect(btnPlugins,    TQT_SIGNAL(clicked()),
-                     this,          TQT_SLOT(slotBtnPluginsClicked()));
+    TQObject::connect(btnPower,      TQ_SIGNAL(toggled(bool)),
+                     this,          TQ_SLOT(slotPower(bool)));
+    TQObject::connect(btnQuit,       TQ_SIGNAL(clicked()),
+                     kapp,          TQ_SLOT(quit()));
+    TQObject::connect(btnConfigure,  TQ_SIGNAL(toggled(bool)),
+                     this,          TQ_SLOT(slotConfigure(bool)));
+    TQObject::connect(btnRecording,  TQ_SIGNAL(clicked()),
+                     this,          TQ_SLOT(slotRecord()));
+    TQObject::connect(btnSnooze,     TQ_SIGNAL(toggled(bool)),
+                     this,          TQ_SLOT(slotSnooze(bool)));
+    TQObject::connect(comboStations, TQ_SIGNAL(activated(int)),
+                     this,          TQ_SLOT(slotComboStationSelected(int)));
+    TQObject::connect(btnPlugins,    TQ_SIGNAL(clicked()),
+                     this,          TQ_SLOT(slotBtnPluginsClicked()));
 
     // tooltips
 
@@ -224,8 +224,8 @@ bool RadioView::addElement (RadioViewElement *e)
 
 
     e->reparent(this, TQPoint(0, 0), true);
-    TQObject::connect(e,    TQT_SIGNAL(destroyed(TQObject*)),
-                     this, TQT_SLOT(removeElement(TQObject*)));
+    TQObject::connect(e,    TQ_SIGNAL(destroyed(TQObject*)),
+                     this, TQ_SLOT(removeElement(TQObject*)));
     elements.append(e);
     widgetStacks[cls]->addWidget(e);
 
@@ -266,8 +266,8 @@ bool RadioView::removeElement (TQObject *_e)
         e->disconnectI(currentDevice);
 
     RadioViewClass cls = e->getClass();
-    TQObject::disconnect(e,    TQT_SIGNAL(destroyed(TQObject*)),
-                        this, TQT_SLOT(removeElement(TQObject*)));
+    TQObject::disconnect(e,    TQ_SIGNAL(destroyed(TQObject*)),
+                        this, TQ_SLOT(removeElement(TQObject*)));
     widgetStacks[cls]->removeWidget(e);
     elements.remove(e);
 
@@ -544,9 +544,9 @@ ConfigPageInfo RadioView::createConfigurationPage()
         addConfigurationTabFor(i.current(), c);
     }
 
-    configPages.append(TQT_TQOBJECT(c));
-    TQObject::connect(c,    TQT_SIGNAL(destroyed(TQObject *)),
-                     this, TQT_SLOT(slotConfigPageDeleted(TQObject *)));
+    configPages.append(c);
+    TQObject::connect(c,    TQ_SIGNAL(destroyed(TQObject *)),
+                     this, TQ_SLOT(slotConfigPageDeleted(TQObject *)));
 
     return ConfigPageInfo(
         c,
@@ -572,9 +572,9 @@ void RadioView::addConfigurationTabFor(RadioViewElement *e, TQTabWidget *c)
             c->addTab(inf.page, inf.itemName);
         }
 
-        elementConfigPages.push_back(ElementCfg(e, TQT_TQOBJECT(inf.page)));
-        TQObject::connect(inf.page, TQT_SIGNAL(destroyed(TQObject *)),
-                         this, TQT_SLOT(slotElementConfigPageDeleted(TQObject *)));
+        elementConfigPages.push_back(ElementCfg(e, inf.page));
+        TQObject::connect(inf.page, TQ_SIGNAL(destroyed(TQObject *)),
+                         this, TQ_SLOT(slotElementConfigPageDeleted(TQObject *)));
     }
 }
 
@@ -592,9 +592,9 @@ void RadioView::addCommonConfigurationTab(TQTabWidget *c)
 
     c->addTab(f, i18n("Common"));
 
-    elementConfigPages.push_back(ElementCfg(TQT_TQOBJECT(f)));
-    TQObject::connect(f,    TQT_SIGNAL(destroyed(TQObject *)),
-                     this, TQT_SLOT(slotElementConfigPageDeleted(TQObject *)));
+    elementConfigPages.push_back(ElementCfg(f));
+    TQObject::connect(f,    TQ_SIGNAL(destroyed(TQObject *)),
+                     this, TQ_SLOT(slotElementConfigPageDeleted(TQObject *)));
 }
 
 
