@@ -12,8 +12,8 @@ void RadioView_SeekerUI::init()
 	Accel = new TQAccel (this);
 	Accel->insertItem (Key_Left,  100);
 	Accel->insertItem (Key_Right, 101);
-	Accel->connectItem (100, sldRange, TQT_SLOT(subtractStep()));
-	Accel->connectItem (101, sldRange, TQT_SLOT(addStep()));
+	Accel->connectItem (100, sldRange, TQ_SLOT(subtractStep()));
+	Accel->connectItem (101, sldRange, TQ_SLOT(addStep()));
 }
 
 void RadioView_SeekerUI::destroy()
