@@ -443,7 +443,7 @@ void V4LRadioConfiguration::selectRadioDevice()
                    i18n("any ( * )").ascii(),
                    this,
                    i18n("Radio Device Selection").ascii(),
-                   TRUE);
+                   true);
     fd.setMode(KFile::File | KFile::ExistingOnly);
     fd.setCaption (i18n("Select Radio Device"));
 
