@@ -120,8 +120,8 @@ TDERadioAboutWidget::TDERadioAboutWidget(const TDEAboutData &aboutData, int layo
 
     vbox = new TQVBoxLayout( mImageFrame, 1 );
     mImageLabel = new TDERadioImageTrackLabel( mImageFrame );
-    connect( mImageLabel, TQT_SIGNAL(mouseTrack( int, const TQMouseEvent * )),
-         TQT_SLOT( slotMouseTrack( int, const TQMouseEvent * )) );
+    connect( mImageLabel, TQ_SIGNAL(mouseTrack( int, const TQMouseEvent * )),
+         TQ_SLOT( slotMouseTrack( int, const TQMouseEvent * )) );
     vbox->addStretch(10);
     vbox->addWidget( mImageLabel );
     vbox->addStretch(10);
@@ -147,8 +147,8 @@ TDERadioAboutWidget::TDERadioAboutWidget(const TDEAboutData &aboutData, int layo
     gbox->setColStretch( 2, 10 );
 
     mImageLabel = new TDERadioImageTrackLabel( mImageFrame );
-    connect( mImageLabel, TQT_SIGNAL(mouseTrack( int, const TQMouseEvent * )),
-         TQT_SLOT( slotMouseTrack( int, const TQMouseEvent * )) );
+    connect( mImageLabel, TQ_SIGNAL(mouseTrack( int, const TQMouseEvent * )),
+         TQ_SLOT( slotMouseTrack( int, const TQMouseEvent * )) );
     gbox->addWidget( mImageLabel, 1, 1 );
     gbox->activate();
   }
@@ -171,8 +171,8 @@ TDERadioAboutWidget::TDERadioAboutWidget(const TDEAboutData &aboutData, int layo
 
     vbox = new TQVBoxLayout( mImageFrame, 1 );
     mImageLabel = new TDERadioImageTrackLabel( mImageFrame );
-    connect( mImageLabel, TQT_SIGNAL(mouseTrack( int, const TQMouseEvent * )),
-         TQT_SLOT( slotMouseTrack( int, const TQMouseEvent * )) );
+    connect( mImageLabel, TQ_SIGNAL(mouseTrack( int, const TQMouseEvent * )),
+         TQ_SLOT( slotMouseTrack( int, const TQMouseEvent * )) );
     vbox->addStretch(10);
     vbox->addWidget( mImageLabel );
     vbox->addStretch(10);
@@ -235,10 +235,10 @@ TQFrame *TDERadioAboutWidget::addTextPage( const TQString &title,
     browser->setMinimumHeight( fontMetrics().lineSpacing()*numLines );
 
     vbox->addWidget(browser);
-    connect(browser, TQT_SIGNAL(urlClick(const TQString &)),
-        TQT_SLOT(slotUrlClick(const TQString &)));
-    connect(browser, TQT_SIGNAL(mailClick(const TQString &,const TQString &)),
-        TQT_SLOT(slotMailClick(const TQString &,const TQString &)));
+    connect(browser, TQ_SIGNAL(urlClick(const TQString &)),
+        TQ_SLOT(slotUrlClick(const TQString &)));
+    connect(browser, TQ_SIGNAL(mailClick(const TQString &,const TQString &)),
+        TQ_SLOT(slotMailClick(const TQString &,const TQString &)));
   }
   else
   {
@@ -293,10 +293,10 @@ TDEAboutContainer *TDERadioAboutWidget::addContainerPage( const TQString &title,
     mContainerList[ mContainerList.size()-1 ]=container;
   }
 
-  connect(container, TQT_SIGNAL(urlClick(const TQString &)),
-      TQT_SLOT(slotUrlClick(const TQString &)));
-  connect(container, TQT_SIGNAL(mailClick(const TQString &,const TQString &)),
-      TQT_SLOT(slotMailClick(const TQString &,const TQString &)));
+  connect(container, TQ_SIGNAL(urlClick(const TQString &)),
+      TQ_SLOT(slotUrlClick(const TQString &)));
+  connect(container, TQ_SIGNAL(mailClick(const TQString &,const TQString &)),
+      TQ_SLOT(slotMailClick(const TQString &,const TQString &)));
 
   return container;
 }
@@ -325,10 +325,10 @@ TDEAboutContainer *TDERadioAboutWidget::addScrolledContainerPage(
   scrollView->addChild( container );
 
 
-  connect(container, TQT_SIGNAL(urlClick(const TQString &)),
-      TQT_SLOT(slotUrlClick(const TQString &)));
-  connect(container, TQT_SIGNAL(mailClick(const TQString &,const TQString &)),
-      TQT_SLOT(slotMailClick(const TQString &,const TQString &)));
+  connect(container, TQ_SIGNAL(urlClick(const TQString &)),
+      TQ_SLOT(slotUrlClick(const TQString &)));
+  connect(container, TQ_SIGNAL(mailClick(const TQString &,const TQString &)),
+      TQ_SLOT(slotMailClick(const TQString &,const TQString &)));
 
   return container;
 }
@@ -362,10 +362,10 @@ TDEAboutContainer *TDERadioAboutWidget::addContainer( int childAlignment,
     mContainerList[ mContainerList.size()-1 ]=container;
   }
 
-  connect(container, TQT_SIGNAL(urlClick(const TQString &)),
-      TQT_SLOT(slotUrlClick(const TQString &)));
-  connect(container, TQT_SIGNAL(mailClick(const TQString &,const TQString &)),
-      TQT_SLOT(slotMailClick(const TQString &,const TQString &)));
+  connect(container, TQ_SIGNAL(urlClick(const TQString &)),
+      TQ_SLOT(slotUrlClick(const TQString &)));
+  connect(container, TQ_SIGNAL(mailClick(const TQString &,const TQString &)),
+      TQ_SLOT(slotMailClick(const TQString &,const TQString &)));
 
   return container;
 }
@@ -516,8 +516,8 @@ void TDERadioAboutWidget::setAboutData(const TDEAboutData &_aboutData)
         url->setURL(aboutData->homepage());
         appPage->addWidget( url );
         // FIXME
-        connect( url, TQT_SIGNAL(leftClickedURL(const TQString &)),
-                 this, TQT_SLOT(slotUrlClick(const TQString &)));
+        connect( url, TQ_SIGNAL(leftClickedURL(const TQString &)),
+                 this, TQ_SLOT(slotUrlClick(const TQString &)));
     }
 
     int authorCount = aboutData->authors().count();
