@@ -23,11 +23,11 @@
 #endif
 
 #include <tqobject.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include "radiodevice_interfaces.h"
 #include "seekhelper.h"
 
-class KDE_EXPORT FrequencySeekHelper : public TQObject,
+class TDE_EXPORT FrequencySeekHelper : public TQObject,
                                        public SeekHelper,
                                        public IFrequencyRadioClient
 {
