@@ -23,7 +23,7 @@
 #endif
 
 #include <tqstringlist.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 #include "radio_interfaces.h"
 #include "stationselection_interfaces.h"
@@ -35,7 +35,7 @@
 
 class RadioStationListView;
 
-class KDE_EXPORT StationSelector : public StationSelectorUI,
+class TDE_EXPORT StationSelector : public StationSelectorUI,
                                    public IRadioClient,
                                    public IStationSelectionClient
 {
